GridOptionsBuilder
============================================
The ``GridOptionsBuilder`` class may be used to help defining `gridOptions <https://www.ag-grid.com/javascript-data-grid/grid-properties/>`_ dictionary.
Even though grid's configuration can be done by passing a dictionary, it is recommended to use the ``GridOptionsBuilder``.

.. automodule:: st_aggrid

.. autoclass:: st_aggrid.GridOptionsBuilder
    :members: